---
title: '[공지] KSNET 장애로 인한 간헐적  timeout 이슈 (조치완료)'
category: 공지사항
tags:
  - 공지사항
datetime: 2024-11-09T04:30:51.861Z
---

안녕하세요. 포트원 고객지원팀입니다.

2024년 11월 09일 11시 38분부터 12시 38분까지 KSNET의 내부 오류로 결제가 정상 처리되지 않는 이슈가 있어 안내해 드리니 참고 부탁드립니다.

- **KSNET 장애로 인한 간헐적 timeout  이슈**
- **KSNET 을 사용한 결제가 정상적으로 진행되지 않을 수 있습니다.**
- **시간 : 2024.11.09 11:38\~12:38**
